#!/bin/sh

# Copyright 2001, 2002 (C) Metacosm development team

case "$1" in
  en)
    LG=en
    ;;
  fr)
    LG=fr
    ;;
  *)
    echo "Usage: `basename $0` [en|fr]"
    exit
esac

EN_ALT_EN="English version"
EN_ALT_FR="French version"
FR_ALT_EN="Version anglaise"
FR_ALT_FR="Version franaise"

BASE_IMAGES_DIR="images"
EN_IMAGE=${BASE_IMAGES_DIR}/en.jpg
FR_IMAGE=${BASE_IMAGES_DIR}/fr.jpg
MAINTAINERS_FILE="maintainers"
MAINTAINERS_MAIL="maintainers.mail"
STATUS_FILE="status"

#Produce one table line by RFC
function fillTable()
{
  # Order SGML files, by alphabetic order
  rm -f .TMP_FILE
  for j in `find $* -name "*.sgml"`
  {
    echo "`basename ${j}`;${j}" >> .TMP_FILE 
  }
  doc=`sort ./.TMP_FILE | cut -d";" -f2`
  rm -f .TMP_FILE

  for i in ${doc}
  {
    NAME=`basename ${i} .sgml`

    doctype=`grep -i "<\!doctype" $i | tr [:upper:] [:lower:]`
    case "$doctype" in
      *docbook*) DTD="docbook"
                 VERSION="`grep -i "<revnumber>" $i | head -n1 | sed 's/<revnumber>\(.*\)<\/revnumber>/\1/'`,`grep -i "<date>" $i | head -n1 | sed 's/<date>\(.*\)<\/date>/\1/'`"
		 HTML_INDEX="t1.html"
                 ;;
      *metacosm*) DTD="metacosm"
                  VERSION=`grep -i "<date>" $i | sed s/"<date>"//`
		  HTML_INDEX="${NAME}.html"
                  ;;
      *linuxdoc*) DTD="linuxdoc"
                  VERSION=`grep -i "<date>" $i | sed s/"<date>"//`
		  HTML_INDEX="${NAME}.html"
                  ;;
      *) echo "Unknown DTD"
               return
               ;;
     esac

    case "$i" in
      */en/*) DOC_LG="en"
                IMAGE=${EN_IMAGE}
                BASE_DIR="en"
	        case "$LG" in
	          en) ALT_IMAGE=${EN_ALT_EN}
                  ;;
                  fr) ALT_IMAGE=${FR_ALT_EN}
		  ;;
                esac
                ;;
      */fr/*) DOC_LG="fr"
                IMAGE=${FR_IMAGE}
                BASE_DIR="fr"
                case "$LG" in
                  en) ALT_IMAGE=${EN_ALT_FR}
                  ;;
                  fr) ALT_IMAGE=${FR_ALT_FR}
                  ;;
	        esac
		;;
    esac

    TOP_DIR="${BASE_DIR}/RFC"
    SGML_DIR="${TOP_DIR}"
    HTML_DIR="${TOP_DIR}/html/${NAME}"
    PS_DIR="${TOP_DIR}/ps"
    TXT_DIR="${TOP_DIR}/txt"
    WEB_SGML_DIR="${TOP_DIR}/websgml"
    CVS_DIR="RFC/${BASE_DIR}"

    HTML="${HTML_DIR}/${HTML_INDEX}"
    PS="${PS_DIR}/${NAME}.ps.gz"
    SGML="${SGML_DIR}/${NAME}.sgml"
    TXT="${TXT_DIR}/${NAME}.txt"
    WEB_SGML="${WEB_SGML_DIR}/${NAME}.sgml.html"

    CVS="http://savannah.nongnu.org/cgi-bin/viewcvs/*checkout*/metacosm/${CVS_DIR}/${NAME}.sgml?content-type=text/plain"

    MAINTAINER_INFO=`grep -E "${NAME} ${DOC_LG}" ${MAINTAINERS_FILE}`
    if [ -z "${MAINTAINER_INFO}" ]
    then
      echo "Doc ${NAME} not defined in ${MAINTAINERS_FILE}"
      return
    fi
    MAINTAINER=`echo ${MAINTAINER_INFO} | cut -d" " -f4`
    MAIL=`grep "${MAINTAINER}" ${MAINTAINERS_MAIL} | cut -d" " -f2`
    RAW_STATE=`echo ${MAINTAINER_INFO} | cut -d" " -f3`
    STATE=`grep -E "${RAW_STATE} ${LG} " ${STATUS_FILE} | cut -d" " -f3`
    if [ -z "${STATE}" ]
    then
      echo "Status ${RAW_STATE} not defined in ${STATUS_FILE}"
      return
    fi

    echo "
<tr> 
  <td><img src=\"${IMAGE}\" alt=\"${ALT_IMAGE}\" border=\"0\"/></td>
  <td><a href=\"${HTML}\">${NAME}</a></td>
  <td><a href=\"${CVS}\"><b>[cvs sgml]</b></a></td>
  <td>${VERSION}</td>
  <td>${STATE}</td>
  <td><a href=\"${TXT}\">[txt]</a></td>
  <td><a href=\"${PS}\">[ps.gz]</a></td>
  <td><a href=\"${SGML}\">[sgml]</a></td>
  <td><a href=\"${WEB_SGML}\">[web&nbsp;sgml]</a></td>
  <td><a href=\"mailto:${MAIL}\">${MAINTAINER}</a></td>
  <td>${DTD}</td>
</tr>"
  }
}

function header()
{
  case "$LG" in
    en) echo "<?xml version=\"1.0\" encoding=\"iso-8859-15\" ?>
<!DOCTYPE html
          PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\"
          \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">
<html lang=\"en\">

  <head>
    <meta name=\"author\" content=\"Metacosm development team\"/>
    <meta name=\"keywords\" content=\"metacosm, documentation, document, design, architecture\"/>
    <meta name=\"description\" lang=\"en\" content=\"Metacosm, documents, design and architecture\"/>
    <title>Documents, design &amp; architecture</title>
  </head>
  <body>

    <div> <!-- The header will be inserted here -->
<!-- Begin page content -->

<p>This page has been automatically generated by a script.</p>
<p>Documents are written in SGML and converted into several formats with SGML-tools (v1 or 2).</p>
<p>SGML linuxdoc-DTD is used by the Linux Documentation Project and is easily available.</p>
<p>SGML metacosm-DTD is an ugly thing created to make us lazy, and is available <a href=\"http://savannah.nongnu.org/cgi-bin/viewcvs/*checkout*/metacosm/RFC/metacosm.dtd?content-type=text/plain\">here</a>.</p>
<p>SGML docbook-DTD is used with special entities defined in <a href=\"http://savannah.nongnu.org/cgi-bin/viewcvs/*checkout*/metacosm/RFC/en.metacosm.ent?content-type=text/plain\">en.metacosm.ent</a> and <a href=\"http://savannah.nongnu.org/cgi-bin/viewcvs/*checkout*/metacosm/RFC/fr.metacosm.ent?content-type=text/plain\">fr.metacosm.ent</a> files.</p>
<p>Last versions of documents are available in SGML format only in the <a href=\"http://savannah.nongnu.org/cgi-bin/viewcvs/*checkout*/metacosm/RFC\">CVS</a>.</p>"
        ;;
    fr) echo "<?xml version=\"1.0\" encoding=\"iso-8859-15\" ?>
<!DOCTYPE html
          PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\"
          \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">
<html lang=\"fr\">

  <head>
    <meta name=\"author\" content=\"quipe de dveloppement de Metacosm\"/>
    <meta name=\"keywords\" content=\"metacosm, documentation, document, design, architecture\"/>
    <meta name=\"description\" lang=\"fr\" content=\"Metacosm, documents, design et architecture\"/>
    <title>Documents, design &amp; architecture</title>
  </head>
  <body>

    <div> <!-- The header will be inserted here -->
<!-- Begin page content -->

<p>Cette page a t automatiquement gnre par un script.</p>
<p>Les documents sont crits en SGML et convertis en diffrents formats grce  SGML-tools (v1 ou 2).</p>
<p>SGML linuxdoc-DTD est utilis par le Linux Documentation Project et peut s'obtenir facilement.</p>
<p>SGML metacosm-DTD est une bidouille cre par nous qui sommes paresseux, et est disponible <a href=\"http://savannah.nongnu.org/cgi-bin/viewcvs/*checkout*/metacosm/RFC/metacosm.dtd?content-type=text/plain\">ici</a>.</p>
<p>SGML docbook-DTD est utilis avec des entits spciales dfinies dans les fichiers <a href=\"http://savannah.nongnu.org/cgi-bin/viewcvs/*checkout*/metacosm/RFC/en.metacosm.ent?content-type=text/plain\">en.metacosm.ent</a> et <a href=\"http://savannah.nongnu.org/cgi-bin/viewcvs/*checkout*/metacosm/RFC/fr.metacosm.ent?content-type=text/plain\">fr.metacosm.ent</a>.</p>
<p>Les dernires versions des documents sont disponibles au format SGML seulement dans le <a href=\"http://savannah.nongnu.org/cgi-bin/viewcvs/*checkout*/metacosm/RFC\">CVS</a>.</p>"
        ;;
    esac
}

function available_states()
{
  case "$LG" in
    en) echo "Possible states&nbsp;:"
        ;;
    fr) echo "tats possibles&nbsp;:"
        ;;
  esac
  echo "
<ul>
`grep " ${LG} " ${STATUS_FILE} | cut -d " " -f3 | sort | sed s/".*"/"  <li>&<\/li>"/`
</ul>
<p>"
  case "$LG" in
    en) echo "OBSOLETE documents are just available in the CVS Attic directory."
        ;;
    fr) echo "Les documents OBSOLTES sont seulement disponibles dans le rpertoire Attic du CVS."
        ;;
  esac
	echo "</p>"
}

function footer()
{
echo "<!-- End page content -->

    </div> <!-- The footer will be inserted here -->
    
    <!-- timestamp start -->
    $Date: 2003/03/03 22:00:48 $ $Author: ruffy $
    <!-- timestamp end -->

  </body>
</html>
<!--
Local Variables: ***
mode: xml ***
End: ***
-->"
}

function table_header()
{
  case "$LG" in
    en) echo "
<table border=\"0\" summary=\"Our documents available in several formats\">
<tr>
  <th>Lang.</th>
  <th>$1</th>
  <th>CVS Version</th>
  <th>Version [html]</th>
  <th>State</th>
  <th>txt</th>
  <th>ps.gz</th>
  <th>sgml</th>
  <th>web sgml</th>
  <th>Maintainer</th>
  <th>DTD</th>
</tr>"
        ;;
    fr) echo "
		<table border=\"0\" summary=\"Nos documents disponibles en plusieurs formats\">
<tr>
  <th>Lang.</th>
  <th>$1</th>
  <th>CVS Version</th>
  <th>Version [html]</th>
  <th>tat</th>
  <th>txt</th>
  <th>ps.gz</th>
  <th>sgml</th>
  <th>web sgml</th>
  <th>Mainteneur</th>
  <th>DTD</th>
</tr>"
        ;;
  esac
}

function table_footer()
{
  echo "
</table>"
}

function title()
{
  echo "
<span class=\"sectiontitle\">$1</span>"
}

function javadoc_table()
{
  echo "
<table border=\"0\" summary=\"Javadoc\">
<tr>
  <td><img src=\"${EN_IMAGE}\" alt=\"${FR_ALT_EN}\" border=\"0\"/></td>"
  case "$LG" in
    en) echo "
  <td><a href=\"en/doc/index.html\">Javadoc documentation for all packages (not always up-to-date)</a></td>"
       ;;
    fr) echo "
  <td><a href=\"en/doc/index.html\">Documentation Javadoc pour l'ensemble des paquetages (pas toujours  jour)</a></td>"
       ;;
  esac

  echo "
</tr>
</table>"
}

#MAIN

header
available_states
title RFC
table_header RFC
fillTable ./en/RFC ./fr/RFC
table_footer
title Javadoc
javadoc_table
footer
